@@ -4,12 +4,13 @@ import json
 
 class Client(object):
 
-    def __init__(self, client_id, client_secret, bearer_token=None, refresh_token=None):
+    def __init__(self, client_id, client_secret, redirect_uri, bearer_token=None, refresh_token=None):
         self.client_id = client_id
         self.client_secret = client_secret
         self.base_url = "https://api.freshbooks.com"
         self.authorization_url = "https://my.freshbooks.com/service/auth/oauth/authorize"
         self.token_url = "https://api.freshbooks.com/auth/oauth/token"
+        self.redirect_uri =  redirect_uri
         self.bearer_token = bearer_token
         self.refresh_token = refresh_token
 
